@@ -1,39 +1,44 @@
-#[allow(unused_imports, dead_code)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
-use error_chain::bail;
+use ate::mesh::FatalTerminate;
 use ate::prelude::*;
+use ate::utils::LoadProgress;
+use error_chain::bail;
 use std::io::ErrorKind;
 use std::sync::Arc;
 use std::time::Duration;
 use tokio::select;
-use ate::mesh::FatalTerminate;
-use ate::utils::LoadProgress;
+#[allow(unused_imports, dead_code)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 
 use crate::fs::AteFS;
 use crate::opts::*;
 use crate::umount;
 
 use fuse3::raw::prelude::*;
-use fuse3::{MountOptions};
+use fuse3::MountOptions;
 
 fn ctrl_channel() -> tokio::sync::watch::Receiver<bool> {
     let (sender, receiver) = tokio::sync::watch::channel(false);
     ctrlc_async::set_handler(move || {
         let _ = sender.send(true);
-    }).unwrap();
+    })
+    .unwrap();
     receiver
 }
 
-pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>, session: AteSessionType, no_auth: bool)
--> Result<(), AteError>
-{
+pub async fn main_mount(
+    mount: OptsMount,
+    conf: ConfAte,
+    group: Option<String>,
+    session: AteSessionType,
+    no_auth: bool,
+) -> Result<(), AteError> {
     let uid = match mount.uid {
         Some(a) => a,
-        None => unsafe { libc::getuid() }
+        None => unsafe { libc::getuid() },
     };
     let gid = match mount.gid {
         Some(a) => a,
-        None => unsafe { libc::getgid() }
+        None => unsafe { libc::getgid() },
     };
 
     debug!("uid: {}", uid);
@@ -53,16 +58,23 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
     debug!("read_only: {}", mount.read_only);
     debug!("write_back: {}", mount.write_back);
     debug!("non_empty: {}", mount.non_empty);
-    
+
     let mut conf = conf.clone();
     conf.configured_for(mount.configured_for);
     conf.log_format.meta = mount.meta_format;
     conf.log_format.data = mount.data_format;
-    conf.log_path = mount.log_path.as_ref().map(|a| shellexpand::tilde(a).to_string());
-    conf.backup_path = mount.backup_path.as_ref().map(|a| shellexpand::tilde(a).to_string());
+    conf.log_path = mount
+        .log_path
+        .as_ref()
+        .map(|a| shellexpand::tilde(a).to_string());
+    conf.backup_path = mount
+        .backup_path
+        .as_ref()
+        .map(|a| shellexpand::tilde(a).to_string());
     conf.recovery_mode = mount.recovery_mode;
     conf.compact_bootstrap = mount.compact_now;
-    conf.compact_mode = mount.compact_mode
+    conf.compact_mode = mount
+        .compact_mode
         .with_growth_factor(mount.compact_threshold_factor)
         .with_growth_size(mount.compact_threshold_size)
         .with_timer_value(Duration::from_secs(mount.compact_timer));
@@ -70,10 +82,13 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
     info!("configured_for: {:?}", mount.configured_for);
     info!("meta_format: {:?}", mount.meta_format);
     info!("data_format: {:?}", mount.data_format);
-    info!("log_path: {}", match conf.log_path.as_ref() {
-        Some(a) => a.as_str(),
-        None => "(memory)"
-    });
+    info!(
+        "log_path: {}",
+        match conf.log_path.as_ref() {
+            Some(a) => a.as_str(),
+            None => "(memory)",
+        }
+    );
     info!("log_temp: {}", mount.temp);
     info!("mount_path: {}", mount.mount_path);
     match &mount.remote_name {
@@ -81,17 +96,16 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
         None => info!("remote: local-only"),
     };
 
-    let builder = ChainBuilder::new(&conf)
-        .await
-        .temporal(mount.temp);
+    let builder = ChainBuilder::new(&conf).await.temporal(mount.temp);
 
     // Create a progress bar loader
-    let mut progress_local = LoadProgress::default();
-    let mut progress_remote = LoadProgress::default();
+    let mut progress_local = LoadProgress::new(std::io::stdout());
+    let mut progress_remote = LoadProgress::new(std::io::stdout());
     progress_local.units = pbr::Units::Bytes;
     progress_local.msg_done = "Downloading latest events from server...".to_string();
-    progress_remote.msg_done = "Loaded the remote chain-of-trust, proceeding to mount the file system.".to_string();
-    eprint!("Loading the chain-of-trust...");
+    progress_remote.msg_done =
+        "Loaded the remote chain-of-trust, proceeding to mount the file system.".to_string();
+    print!("Loading the chain-of-trust...");
 
     // We create a chain with a specific key (this is used for the file name it creates)
     debug!("chain-init");
@@ -99,11 +113,10 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
     let chain = match mount.remote_name {
         None => {
             let trust = match &mount.configured_for {
-                ConfiguredFor::BestSecurity |
-                ConfiguredFor::SmallestSize => {
+                ConfiguredFor::BestSecurity | ConfiguredFor::SmallestSize => {
                     TrustMode::Centralized(CentralizedRole::Client)
-                },
-                _ => TrustMode::Distributed
+                }
+                _ => TrustMode::Distributed,
             };
             Ok(Arc::new(
                 Chain::new_ext(
@@ -112,17 +125,24 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
                     Some(Box::new(progress_local)),
                     true,
                     trust,
-                    trust
-                ).await?
+                    trust,
+                )
+                .await?,
             ))
-        },
+        }
         Some(remote) => {
-            registry = ate::mesh::Registry::new(&conf).await
-                .temporal(mount.temp);
-            
-            let guard = registry.open_ext(&mount.remote, &ChainKey::from(remote), progress_local, progress_remote).await?;
+            registry = ate::mesh::Registry::new(&conf).await.temporal(mount.temp);
+
+            let guard = registry
+                .open_ext(
+                    &mount.remote,
+                    &ChainKey::from(remote),
+                    progress_local,
+                    progress_remote,
+                )
+                .await?;
             Ok(guard.as_arc())
-        },
+        }
     };
 
     // Perform specific error handling (otherwise let it propogate up)
@@ -131,16 +151,18 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
         Err(ChainCreationError(ChainCreationErrorKind::ServerRejected(reason), _)) => {
             match reason {
                 FatalTerminate::Denied { reason } => {
-                    eprintln!("Access to this file system was denied by the server");
-                    eprintln!("---");
-                    eprintln!("{}", reason);
+                    println!("Access to this file system was denied by the server");
+                    println!("---");
+                    println!("{}", reason);
                     std::process::exit(1);
-                },
+                }
                 _ => {
-                    bail!(AteErrorKind::ChainCreationError(ChainCreationErrorKind::ServerRejected(reason)));
+                    bail!(AteErrorKind::ChainCreationError(
+                        ChainCreationErrorKind::ServerRejected(reason)
+                    ));
                 }
             }
-        },
+        }
         Err(err) => {
             bail!(err);
         }
@@ -158,8 +180,8 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
 
     // Create the mount point
     let mount_path = mount.mount_path.clone();
-    let mount_join = Session::new(mount_options)
-        .mount_with_unprivileged(AteFS::new(
+    let mount_join = Session::new(mount_options).mount_with_unprivileged(
+        AteFS::new(
             chain,
             group,
             session,
@@ -168,7 +190,10 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
             no_auth,
             mount.impersonate_uid,
             mount.umask,
-        ).await, mount.mount_path);
+        )
+        .await,
+        mount.mount_path,
+    );
 
     // Install a ctrl-c command
     info!("mounting file-system and entering main loop");
@@ -186,13 +211,12 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
     }
 
     // Main loop
-    eprintln!("Press ctrl-c to exit");
-    select!
-    {
+    println!("Press ctrl-c to exit");
+    select! {
         // Wait for a ctrl-c
         _ = ctrl_c.changed() => {
             umount::unmount(std::path::Path::new(mount_path.as_str()))?;
-            eprintln!("Goodbye!");
+            println!("Goodbye!");
             return Ok(());
         }
 
@@ -205,20 +229,22 @@ pub async fn main_mount(mount: OptsMount, conf: ConfAte, group: Option<String>,
                         return Ok(())
                     }
                     error!("{}", err);
+                    println!("Mount failed");
                     let _ = umount::unmount(std::path::Path::new(mount_path.as_str()));
                     std::process::exit(1);
                 }
                 Err(err) => {
                     error!("{}", err);
+                    println!("Mount failed");
                     let _ = umount::unmount(std::path::Path::new(mount_path.as_str()));
                     std::process::exit(1);
                 }
                 _ => {
-                    eprintln!("Shutdown");
+                    println!("Mount shutdown");
                     let _ = umount::unmount(std::path::Path::new(mount_path.as_str()));
                     return Ok(());
                 }
             }
         }
     }
-}
\ No newline at end of file
+}
