@@ -1,15 +1,13 @@
-#[allow(unused_imports)]
-use tracing::{info, warn, debug, error, trace, instrument, span, Level};
 use ate::prelude::*;
 use ate_auth::opt::*;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, instrument, span, trace, warn, Level};
 use url::Url;
 
 use ate::compact::CompactMode;
 
 #[cfg(feature = "enable_tokera")]
-use {
-    tokera::opt::*
-};
+use tokera::opt::{OptsContract, OptsLogin, OptsLogout, OptsService, OptsWallet};
 
 use clap::Parser;
 
@@ -126,11 +124,11 @@ pub enum SubCommand {
 #[derive(Parser)]
 pub struct OptsMount {
     /// Path to directory that the file system will be mounted at
-    #[clap(index=1)]
+    #[clap(index = 1)]
     pub mount_path: String,
     /// Name of the file-system to be mounted (e.g. myfs).
     /// If this URL is not specified then data will only be stored in a local chain-of-trust
-    #[clap(index=2)]
+    #[clap(index = 2)]
     pub remote_name: Option<String>,
     /// URL where the data is remotely stored on a distributed commit log.
     #[clap(short, long, default_value = "ws://tokera.com/db")]
@@ -185,7 +183,7 @@ pub struct OptsMount {
     pub non_empty: bool,
     /// For files and directories that the authenticated user owns, translate the UID and GID to the local machine ids instead of the global ones.
     #[clap(short, long)]
-    pub impersonate_uid: bool, 
+    pub impersonate_uid: bool,
     /// Configure the log file for <raw>, <barebone>, <speed>, <compatibility>, <balanced> or <security>
     #[clap(long, default_value = "speed")]
     pub configured_for: ate::conf::ConfiguredFor,
@@ -210,4 +208,4 @@ pub struct OptsMount {
     /// Size of growth in bytes in the log file which will trigger compaction (default: 100MB) - this argument is ignored if you select a compact_mode that has no growth trigger
     #[clap(long, default_value = "104857600")]
     pub compact_threshold_size: u64,
-}
\ No newline at end of file
+}
